# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt
from .v1_cross_version_object_reference import V1CrossVersionObjectReference

class V1HorizontalPodAutoscalerSpec(BaseModel):
    """
    specification of a horizontal pod autoscaler.  # noqa: E501
    """
    max_replicas: StrictInt = Field(..., alias="maxReplicas", description="maxReplicas is the upper limit for the number of pods that can be set by the autoscaler; cannot be smaller than MinReplicas.")
    min_replicas: Optional[StrictInt] = Field(None, alias="minReplicas", description="minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.")
    scale_target_ref: V1CrossVersionObjectReference = Field(..., alias="scaleTargetRef")
    target_cpu_utilization_percentage: Optional[StrictInt] = Field(None, alias="targetCPUUtilizationPercentage", description="targetCPUUtilizationPercentage is the target average CPU utilization (represented as a percentage of requested CPU) over all the pods; if not specified the default autoscaling policy will be used.")
    __properties = ["maxReplicas", "minReplicas", "scaleTargetRef", "targetCPUUtilizationPercentage"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1HorizontalPodAutoscalerSpec:
        """Create an instance of V1HorizontalPodAutoscalerSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of scale_target_ref
        if self.scale_target_ref:
            _dict['scaleTargetRef'] = self.scale_target_ref.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1HorizontalPodAutoscalerSpec:
        """Create an instance of V1HorizontalPodAutoscalerSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1HorizontalPodAutoscalerSpec.parse_obj(obj)

        _obj = V1HorizontalPodAutoscalerSpec.parse_obj({
            "max_replicas": obj.get("maxReplicas"),
            "min_replicas": obj.get("minReplicas"),
            "scale_target_ref": V1CrossVersionObjectReference.from_dict(obj.get("scaleTargetRef")) if obj.get("scaleTargetRef") is not None else None,
            "target_cpu_utilization_percentage": obj.get("targetCPUUtilizationPercentage")
        })
        return _obj


