# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class V1beta3PriorityLevelConfigurationCondition(BaseModel):
    """
    PriorityLevelConfigurationCondition defines the condition of priority level.  # noqa: E501
    """
    last_transition_time: Optional[datetime] = Field(None, alias="lastTransitionTime", description="`lastTransitionTime` is the last time the condition transitioned from one status to another.")
    message: Optional[StrictStr] = Field(None, description="`message` is a human-readable message indicating details about last transition.")
    reason: Optional[StrictStr] = Field(None, description="`reason` is a unique, one-word, CamelCase reason for the condition's last transition.")
    status: Optional[StrictStr] = Field(None, description="`status` is the status of the condition. Can be True, False, Unknown. Required.")
    type: Optional[StrictStr] = Field(None, description="`type` is the type of the condition. Required.")
    __properties = ["lastTransitionTime", "message", "reason", "status", "type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1beta3PriorityLevelConfigurationCondition:
        """Create an instance of V1beta3PriorityLevelConfigurationCondition from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1beta3PriorityLevelConfigurationCondition:
        """Create an instance of V1beta3PriorityLevelConfigurationCondition from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1beta3PriorityLevelConfigurationCondition.parse_obj(obj)

        _obj = V1beta3PriorityLevelConfigurationCondition.parse_obj({
            "last_transition_time": obj.get("lastTransitionTime"),
            "message": obj.get("message"),
            "reason": obj.get("reason"),
            "status": obj.get("status"),
            "type": obj.get("type")
        })
        return _obj


