# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from .v1_rolling_update_stateful_set_strategy import V1RollingUpdateStatefulSetStrategy

class V1StatefulSetUpdateStrategy(BaseModel):
    """
    StatefulSetUpdateStrategy indicates the strategy that the StatefulSet controller will use to perform updates. It includes any additional parameters necessary to perform the update for the indicated strategy.  # noqa: E501
    """
    rolling_update: Optional[V1RollingUpdateStatefulSetStrategy] = Field(None, alias="rollingUpdate")
    type: Optional[StrictStr] = Field(None, description="Type indicates the type of the StatefulSetUpdateStrategy. Default is RollingUpdate.")
    __properties = ["rollingUpdate", "type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1StatefulSetUpdateStrategy:
        """Create an instance of V1StatefulSetUpdateStrategy from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of rolling_update
        if self.rolling_update:
            _dict['rollingUpdate'] = self.rolling_update.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1StatefulSetUpdateStrategy:
        """Create an instance of V1StatefulSetUpdateStrategy from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1StatefulSetUpdateStrategy.parse_obj(obj)

        _obj = V1StatefulSetUpdateStrategy.parse_obj({
            "rolling_update": V1RollingUpdateStatefulSetStrategy.from_dict(obj.get("rollingUpdate")) if obj.get("rollingUpdate") is not None else None,
            "type": obj.get("type")
        })
        return _obj


