# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, List, Optional, Union
from pydantic import BaseModel, Field, StrictInt, StrictStr, conbytes, conlist, constr, validator

class V1CertificateSigningRequestSpec(BaseModel):
    """
    CertificateSigningRequestSpec contains the certificate request.  # noqa: E501
    """
    expiration_seconds: Optional[StrictInt] = Field(None, alias="expirationSeconds", description="expirationSeconds is the requested duration of validity of the issued certificate. The certificate signer may issue a certificate with a different validity duration so a client must check the delta between the notBefore and and notAfter fields in the issued certificate to determine the actual duration.  The v1.22+ in-tree implementations of the well-known Kubernetes signers will honor this field as long as the requested duration is not greater than the maximum duration they will honor per the --cluster-signing-duration CLI flag to the Kubernetes controller manager.  Certificate signers may not honor this field for various reasons:    1. Old signer that is unaware of the field (such as the in-tree      implementations prior to v1.22)   2. Signer whose configured maximum is shorter than the requested duration   3. Signer whose configured minimum is longer than the requested duration  The minimum valid value for expirationSeconds is 600, i.e. 10 minutes.")
    extra: Optional[Dict[str, conlist(StrictStr)]] = Field(None, description="extra contains extra attributes of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.")
    groups: Optional[conlist(StrictStr)] = Field(None, description="groups contains group membership of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.")
    request: Union[conbytes(strict=True), constr(strict=True)] = Field(..., description="request contains an x509 certificate signing request encoded in a \"CERTIFICATE REQUEST\" PEM block. When serialized as JSON or YAML, the data is additionally base64-encoded.")
    signer_name: StrictStr = Field(..., alias="signerName", description="signerName indicates the requested signer, and is a qualified name.  List/watch requests for CertificateSigningRequests can filter on this field using a \"spec.signerName=NAME\" fieldSelector.  Well-known Kubernetes signers are:  1. \"kubernetes.io/kube-apiserver-client\": issues client certificates that can be used to authenticate to kube-apiserver.   Requests for this signer are never auto-approved by kube-controller-manager, can be issued by the \"csrsigning\" controller in kube-controller-manager.  2. \"kubernetes.io/kube-apiserver-client-kubelet\": issues client certificates that kubelets use to authenticate to kube-apiserver.   Requests for this signer can be auto-approved by the \"csrapproving\" controller in kube-controller-manager, and can be issued by the \"csrsigning\" controller in kube-controller-manager.  3. \"kubernetes.io/kubelet-serving\" issues serving certificates that kubelets use to serve TLS endpoints, which kube-apiserver can connect to securely.   Requests for this signer are never auto-approved by kube-controller-manager, and can be issued by the \"csrsigning\" controller in kube-controller-manager.  More details are available at https://k8s.io/docs/reference/access-authn-authz/certificate-signing-requests/#kubernetes-signers  Custom signerNames can also be specified. The signer defines:  1. Trust distribution: how trust (CA bundles) are distributed.  2. Permitted subjects: and behavior when a disallowed subject is requested.  3. Required, permitted, or forbidden x509 extensions in the request (including whether subjectAltNames are allowed, which types, restrictions on allowed values) and behavior when a disallowed extension is requested.  4. Required, permitted, or forbidden key usages / extended key usages.  5. Expiration/certificate lifetime: whether it is fixed by the signer, configurable by the admin.  6. Whether or not requests for CA certificates are allowed.")
    uid: Optional[StrictStr] = Field(None, description="uid contains the uid of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.")
    usages: Optional[conlist(StrictStr)] = Field(None, description="usages specifies a set of key usages requested in the issued certificate.  Requests for TLS client certificates typically request: \"digital signature\", \"key encipherment\", \"client auth\".  Requests for TLS serving certificates typically request: \"key encipherment\", \"digital signature\", \"server auth\".  Valid values are:  \"signing\", \"digital signature\", \"content commitment\",  \"key encipherment\", \"key agreement\", \"data encipherment\",  \"cert sign\", \"crl sign\", \"encipher only\", \"decipher only\", \"any\",  \"server auth\", \"client auth\",  \"code signing\", \"email protection\", \"s/mime\",  \"ipsec end system\", \"ipsec tunnel\", \"ipsec user\",  \"timestamping\", \"ocsp signing\", \"microsoft sgc\", \"netscape sgc\"")
    username: Optional[StrictStr] = Field(None, description="username contains the name of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable.")
    __properties = ["expirationSeconds", "extra", "groups", "request", "signerName", "uid", "usages", "username"]

    @validator('request')
    def request_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$", value):
            raise ValueError(r"must validate the regular expression /^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CertificateSigningRequestSpec:
        """Create an instance of V1CertificateSigningRequestSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each value in extra (dict of array)
        _field_dict_of_array = {}
        if self.extra:
            for _key in self.extra:
                if self.extra[_key]:
                    _field_dict_of_array[_key] = [
                        _item.to_dict() for _item in self.extra[_key]
                    ]
            _dict['extra'] = _field_dict_of_array
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CertificateSigningRequestSpec:
        """Create an instance of V1CertificateSigningRequestSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1CertificateSigningRequestSpec.parse_obj(obj)

        _obj = V1CertificateSigningRequestSpec.parse_obj({
            "expiration_seconds": obj.get("expirationSeconds"),
            "extra": obj.get("extra"),
            "groups": obj.get("groups"),
            "request": obj.get("request"),
            "signer_name": obj.get("signerName"),
            "uid": obj.get("uid"),
            "usages": obj.get("usages"),
            "username": obj.get("username")
        })
        return _obj


