# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conlist
from .v1_condition import V1Condition
from .v1beta1_type_checking import V1beta1TypeChecking

class V1beta1ValidatingAdmissionPolicyStatus(BaseModel):
    """
    ValidatingAdmissionPolicyStatus represents the status of an admission validation policy.  # noqa: E501
    """
    conditions: Optional[conlist(V1Condition)] = Field(None, description="The conditions represent the latest available observations of a policy's current state.")
    observed_generation: Optional[StrictInt] = Field(None, alias="observedGeneration", description="The generation observed by the controller.")
    type_checking: Optional[V1beta1TypeChecking] = Field(None, alias="typeChecking")
    __properties = ["conditions", "observedGeneration", "typeChecking"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1beta1ValidatingAdmissionPolicyStatus:
        """Create an instance of V1beta1ValidatingAdmissionPolicyStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in conditions (list)
        _items = []
        if self.conditions:
            for _item in self.conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['conditions'] = _items
        # override the default output from pydantic by calling `to_dict()` of type_checking
        if self.type_checking:
            _dict['typeChecking'] = self.type_checking.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1beta1ValidatingAdmissionPolicyStatus:
        """Create an instance of V1beta1ValidatingAdmissionPolicyStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1beta1ValidatingAdmissionPolicyStatus.parse_obj(obj)

        _obj = V1beta1ValidatingAdmissionPolicyStatus.parse_obj({
            "conditions": [V1Condition.from_dict(_item) for _item in obj.get("conditions")] if obj.get("conditions") is not None else None,
            "observed_generation": obj.get("observedGeneration"),
            "type_checking": V1beta1TypeChecking.from_dict(obj.get("typeChecking")) if obj.get("typeChecking") is not None else None
        })
        return _obj


