# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt
from .v1_limit_response import V1LimitResponse

class V1LimitedPriorityLevelConfiguration(BaseModel):
    """
    LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:   - How are requests for this priority level limited?   - What should be done with requests that exceed the limit?  # noqa: E501
    """
    borrowing_limit_percent: Optional[StrictInt] = Field(None, alias="borrowingLimitPercent", description="`borrowingLimitPercent`, if present, configures a limit on how many seats this priority level can borrow from other priority levels. The limit is known as this level's BorrowingConcurrencyLimit (BorrowingCL) and is a limit on the total number of seats that this level may borrow at any one time. This field holds the ratio of that limit to the level's nominal concurrency limit. When this field is non-nil, it must hold a non-negative integer and the limit is calculated as follows.  BorrowingCL(i) = round( NominalCL(i) * borrowingLimitPercent(i)/100.0 )  The value of this field can be more than 100, implying that this priority level can borrow a number of seats that is greater than its own nominal concurrency limit (NominalCL). When this field is left `nil`, the limit is effectively infinite.")
    lendable_percent: Optional[StrictInt] = Field(None, alias="lendablePercent", description="`lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels. The value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.  LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )")
    limit_response: Optional[V1LimitResponse] = Field(None, alias="limitResponse")
    nominal_concurrency_shares: Optional[StrictInt] = Field(None, alias="nominalConcurrencyShares", description="`nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats available at this priority level. This is used both for requests dispatched from this priority level as well as requests dispatched from other priority levels borrowing seats from this level. The server's concurrency limit (ServerCL) is divided among the Limited priority levels in proportion to their NCS values:  NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)  Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level.  If not specified, this field defaults to a value of 30.  Setting this field to zero supports the construction of a \"jail\" for this priority level that is used to hold some request(s)")
    __properties = ["borrowingLimitPercent", "lendablePercent", "limitResponse", "nominalConcurrencyShares"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1LimitedPriorityLevelConfiguration:
        """Create an instance of V1LimitedPriorityLevelConfiguration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of limit_response
        if self.limit_response:
            _dict['limitResponse'] = self.limit_response.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1LimitedPriorityLevelConfiguration:
        """Create an instance of V1LimitedPriorityLevelConfiguration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1LimitedPriorityLevelConfiguration.parse_obj(obj)

        _obj = V1LimitedPriorityLevelConfiguration.parse_obj({
            "borrowing_limit_percent": obj.get("borrowingLimitPercent"),
            "lendable_percent": obj.get("lendablePercent"),
            "limit_response": V1LimitResponse.from_dict(obj.get("limitResponse")) if obj.get("limitResponse") is not None else None,
            "nominal_concurrency_shares": obj.get("nominalConcurrencyShares")
        })
        return _obj


