# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class V1AzureDiskVolumeSource(BaseModel):
    """
    AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod.  # noqa: E501
    """
    caching_mode: Optional[StrictStr] = Field(None, alias="cachingMode", description="cachingMode is the Host Caching mode: None, Read Only, Read Write.")
    disk_name: StrictStr = Field(..., alias="diskName", description="diskName is the Name of the data disk in the blob storage")
    disk_uri: StrictStr = Field(..., alias="diskURI", description="diskURI is the URI of data disk in the blob storage")
    fs_type: Optional[StrictStr] = Field(None, alias="fsType", description="fsType is Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. \"ext4\", \"xfs\", \"ntfs\". Implicitly inferred to be \"ext4\" if unspecified.")
    kind: Optional[StrictStr] = Field(None, description="kind expected values are Shared: multiple blob disks per storage account  Dedicated: single blob disk per storage account  Managed: azure managed data disk (only in managed availability set). defaults to shared")
    read_only: Optional[StrictBool] = Field(None, alias="readOnly", description="readOnly Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.")
    __properties = ["cachingMode", "diskName", "diskURI", "fsType", "kind", "readOnly"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1AzureDiskVolumeSource:
        """Create an instance of V1AzureDiskVolumeSource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1AzureDiskVolumeSource:
        """Create an instance of V1AzureDiskVolumeSource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1AzureDiskVolumeSource.parse_obj(obj)

        _obj = V1AzureDiskVolumeSource.parse_obj({
            "caching_mode": obj.get("cachingMode"),
            "disk_name": obj.get("diskName"),
            "disk_uri": obj.get("diskURI"),
            "fs_type": obj.get("fsType"),
            "kind": obj.get("kind"),
            "read_only": obj.get("readOnly")
        })
        return _obj


