# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from .v1_csi_node_driver import V1CSINodeDriver

class V1CSINodeSpec(BaseModel):
    """
    CSINodeSpec holds information about the specification of all CSI drivers installed on a node  # noqa: E501
    """
    drivers: conlist(V1CSINodeDriver) = Field(..., description="drivers is a list of information of all CSI Drivers existing on a node. If all drivers in the list are uninstalled, this can become empty.")
    __properties = ["drivers"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CSINodeSpec:
        """Create an instance of V1CSINodeSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in drivers (list)
        _items = []
        if self.drivers:
            for _item in self.drivers:
                if _item:
                    _items.append(_item.to_dict())
            _dict['drivers'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CSINodeSpec:
        """Create an instance of V1CSINodeSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1CSINodeSpec.parse_obj(obj)

        _obj = V1CSINodeSpec.parse_obj({
            "drivers": [V1CSINodeDriver.from_dict(_item) for _item in obj.get("drivers")] if obj.get("drivers") is not None else None
        })
        return _obj


