# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field
from .v2_hpa_scaling_rules import V2HPAScalingRules

class V2HorizontalPodAutoscalerBehavior(BaseModel):
    """
    HorizontalPodAutoscalerBehavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively).  # noqa: E501
    """
    scale_down: Optional[V2HPAScalingRules] = Field(None, alias="scaleDown")
    scale_up: Optional[V2HPAScalingRules] = Field(None, alias="scaleUp")
    __properties = ["scaleDown", "scaleUp"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V2HorizontalPodAutoscalerBehavior:
        """Create an instance of V2HorizontalPodAutoscalerBehavior from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of scale_down
        if self.scale_down:
            _dict['scaleDown'] = self.scale_down.to_dict()
        # override the default output from pydantic by calling `to_dict()` of scale_up
        if self.scale_up:
            _dict['scaleUp'] = self.scale_up.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V2HorizontalPodAutoscalerBehavior:
        """Create an instance of V2HorizontalPodAutoscalerBehavior from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V2HorizontalPodAutoscalerBehavior.parse_obj(obj)

        _obj = V2HorizontalPodAutoscalerBehavior.parse_obj({
            "scale_down": V2HPAScalingRules.from_dict(obj.get("scaleDown")) if obj.get("scaleDown") is not None else None,
            "scale_up": V2HPAScalingRules.from_dict(obj.get("scaleUp")) if obj.get("scaleUp") is not None else None
        })
        return _obj


