# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class V1AzureFileVolumeSource(BaseModel):
    """
    AzureFile represents an Azure File Service mount on the host and bind mount to the pod.  # noqa: E501
    """
    read_only: Optional[StrictBool] = Field(None, alias="readOnly", description="readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.")
    secret_name: StrictStr = Field(..., alias="secretName", description="secretName is the  name of secret that contains Azure Storage Account Name and Key")
    share_name: StrictStr = Field(..., alias="shareName", description="shareName is the azure share Name")
    __properties = ["readOnly", "secretName", "shareName"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1AzureFileVolumeSource:
        """Create an instance of V1AzureFileVolumeSource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1AzureFileVolumeSource:
        """Create an instance of V1AzureFileVolumeSource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1AzureFileVolumeSource.parse_obj(obj)

        _obj = V1AzureFileVolumeSource.parse_obj({
            "read_only": obj.get("readOnly"),
            "secret_name": obj.get("secretName"),
            "share_name": obj.get("shareName")
        })
        return _obj


