# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist
from .v1_external_documentation import V1ExternalDocumentation
from .v1_validation_rule import V1ValidationRule

class V1JSONSchemaProps(BaseModel):
    """
    JSONSchemaProps is a JSON-Schema following Specification Draft 4 (http://json-schema.org/).  # noqa: E501
    """
    ref: Optional[StrictStr] = Field(None, alias="$ref")
    var_schema: Optional[StrictStr] = Field(None, alias="$schema")
    additional_items: Optional[Dict[str, Any]] = Field(None, alias="additionalItems", description="JSONSchemaPropsOrBool represents JSONSchemaProps or a boolean value. Defaults to true for the boolean property.")
    additional_properties: Optional[Dict[str, Any]] = Field(None, alias="additionalProperties", description="JSONSchemaPropsOrBool represents JSONSchemaProps or a boolean value. Defaults to true for the boolean property.")
    all_of: Optional[conlist(V1JSONSchemaProps)] = Field(None, alias="allOf")
    any_of: Optional[conlist(V1JSONSchemaProps)] = Field(None, alias="anyOf")
    default: Optional[Dict[str, Any]] = Field(None, description="default is a default value for undefined object fields. Defaulting is a beta feature under the CustomResourceDefaulting feature gate. Defaulting requires spec.preserveUnknownFields to be false.")
    definitions: Optional[Dict[str, V1JSONSchemaProps]] = None
    dependencies: Optional[Dict[str, Dict[str, Any]]] = None
    description: Optional[StrictStr] = None
    enum: Optional[conlist(Dict[str, Any])] = None
    example: Optional[Dict[str, Any]] = Field(None, description="JSON represents any valid JSON value. These types are supported: bool, int64, float64, string, []interface{}, map[string]interface{} and nil.")
    exclusive_maximum: Optional[StrictBool] = Field(None, alias="exclusiveMaximum")
    exclusive_minimum: Optional[StrictBool] = Field(None, alias="exclusiveMinimum")
    external_docs: Optional[V1ExternalDocumentation] = Field(None, alias="externalDocs")
    format: Optional[StrictStr] = Field(None, description="format is an OpenAPI v3 format string. Unknown formats are ignored. The following formats are validated:  - bsonobjectid: a bson object ID, i.e. a 24 characters hex string - uri: an URI as parsed by Golang net/url.ParseRequestURI - email: an email address as parsed by Golang net/mail.ParseAddress - hostname: a valid representation for an Internet host name, as defined by RFC 1034, section 3.1 [RFC1034]. - ipv4: an IPv4 IP as parsed by Golang net.ParseIP - ipv6: an IPv6 IP as parsed by Golang net.ParseIP - cidr: a CIDR as parsed by Golang net.ParseCIDR - mac: a MAC address as parsed by Golang net.ParseMAC - uuid: an UUID that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid3: an UUID3 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?3[0-9a-f]{3}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid4: an UUID4 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?4[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - uuid5: an UUID5 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?5[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - isbn: an ISBN10 or ISBN13 number string like \"0321751043\" or \"978-0321751041\" - isbn10: an ISBN10 number string like \"0321751043\" - isbn13: an ISBN13 number string like \"978-0321751041\" - creditcard: a credit card number defined by the regex ^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6(?:011|5[0-9][0-9])[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|(?:2131|1800|35\\d{3})\\d{11})$ with any non digit characters mixed in - ssn: a U.S. social security number following the regex ^\\d{3}[- ]?\\d{2}[- ]?\\d{4}$ - hexcolor: an hexadecimal color code like \"#FFFFFF: following the regex ^#?([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$ - rgbcolor: an RGB color code like rgb like \"rgb(255,255,2559\" - byte: base64 encoded binary data - password: any kind of string - date: a date string like \"2006-01-02\" as defined by full-date in RFC3339 - duration: a duration string like \"22 ns\" as parsed by Golang time.ParseDuration or compatible with Scala duration format - datetime: a date time string like \"2014-12-15T19:30:20.000Z\" as defined by date-time in RFC3339.")
    id: Optional[StrictStr] = None
    items: Optional[Dict[str, Any]] = Field(None, description="JSONSchemaPropsOrArray represents a value that can either be a JSONSchemaProps or an array of JSONSchemaProps. Mainly here for serialization purposes.")
    max_items: Optional[StrictInt] = Field(None, alias="maxItems")
    max_length: Optional[StrictInt] = Field(None, alias="maxLength")
    max_properties: Optional[StrictInt] = Field(None, alias="maxProperties")
    maximum: Optional[Union[StrictFloat, StrictInt]] = None
    min_items: Optional[StrictInt] = Field(None, alias="minItems")
    min_length: Optional[StrictInt] = Field(None, alias="minLength")
    min_properties: Optional[StrictInt] = Field(None, alias="minProperties")
    minimum: Optional[Union[StrictFloat, StrictInt]] = None
    multiple_of: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="multipleOf")
    var_not: Optional[V1JSONSchemaProps] = Field(None, alias="not")
    nullable: Optional[StrictBool] = None
    one_of: Optional[conlist(V1JSONSchemaProps)] = Field(None, alias="oneOf")
    pattern: Optional[StrictStr] = None
    pattern_properties: Optional[Dict[str, V1JSONSchemaProps]] = Field(None, alias="patternProperties")
    properties: Optional[Dict[str, V1JSONSchemaProps]] = None
    required: Optional[conlist(StrictStr)] = None
    title: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    unique_items: Optional[StrictBool] = Field(None, alias="uniqueItems")
    x_kubernetes_embedded_resource: Optional[StrictBool] = Field(None, alias="x-kubernetes-embedded-resource", description="x-kubernetes-embedded-resource defines that the value is an embedded Kubernetes runtime.Object, with TypeMeta and ObjectMeta. The type must be object. It is allowed to further restrict the embedded object. kind, apiVersion and metadata are validated automatically. x-kubernetes-preserve-unknown-fields is allowed to be true, but does not have to be if the object is fully specified (up to kind, apiVersion, metadata).")
    x_kubernetes_int_or_string: Optional[StrictBool] = Field(None, alias="x-kubernetes-int-or-string", description="x-kubernetes-int-or-string specifies that this value is either an integer or a string. If this is true, an empty type is allowed and type as child of anyOf is permitted if following one of the following patterns:  1) anyOf:    - type: integer    - type: string 2) allOf:    - anyOf:      - type: integer      - type: string    - ... zero or more")
    x_kubernetes_list_map_keys: Optional[conlist(StrictStr)] = Field(None, alias="x-kubernetes-list-map-keys", description="x-kubernetes-list-map-keys annotates an array with the x-kubernetes-list-type `map` by specifying the keys used as the index of the map.  This tag MUST only be used on lists that have the \"x-kubernetes-list-type\" extension set to \"map\". Also, the values specified for this attribute must be a scalar typed field of the child structure (no nesting is supported).  The properties specified must either be required or have a default value, to ensure those properties are present for all list items.")
    x_kubernetes_list_type: Optional[StrictStr] = Field(None, alias="x-kubernetes-list-type", description="x-kubernetes-list-type annotates an array to further describe its topology. This extension must only be used on lists and may have 3 possible values:  1) `atomic`: the list is treated as a single entity, like a scalar.      Atomic lists will be entirely replaced when updated. This extension      may be used on any type of list (struct, scalar, ...). 2) `set`:      Sets are lists that must not have multiple items with the same value. Each      value must be a scalar, an object with x-kubernetes-map-type `atomic` or an      array with x-kubernetes-list-type `atomic`. 3) `map`:      These lists are like maps in that their elements have a non-index key      used to identify them. Order is preserved upon merge. The map tag      must only be used on a list with elements of type object. Defaults to atomic for arrays.")
    x_kubernetes_map_type: Optional[StrictStr] = Field(None, alias="x-kubernetes-map-type", description="x-kubernetes-map-type annotates an object to further describe its topology. This extension must only be used when type is object and may have 2 possible values:  1) `granular`:      These maps are actual maps (key-value pairs) and each fields are independent      from each other (they can each be manipulated by separate actors). This is      the default behaviour for all maps. 2) `atomic`: the list is treated as a single entity, like a scalar.      Atomic maps will be entirely replaced when updated.")
    x_kubernetes_preserve_unknown_fields: Optional[StrictBool] = Field(None, alias="x-kubernetes-preserve-unknown-fields", description="x-kubernetes-preserve-unknown-fields stops the API server decoding step from pruning fields which are not specified in the validation schema. This affects fields recursively, but switches back to normal pruning behaviour if nested properties or additionalProperties are specified in the schema. This can either be true or undefined. False is forbidden.")
    x_kubernetes_validations: Optional[conlist(V1ValidationRule)] = Field(None, alias="x-kubernetes-validations", description="x-kubernetes-validations describes a list of validation rules written in the CEL expression language. This field is an alpha-level. Using this field requires the feature gate `CustomResourceValidationExpressions` to be enabled.")
    __properties = ["$ref", "$schema", "additionalItems", "additionalProperties", "allOf", "anyOf", "default", "definitions", "dependencies", "description", "enum", "example", "exclusiveMaximum", "exclusiveMinimum", "externalDocs", "format", "id", "items", "maxItems", "maxLength", "maxProperties", "maximum", "minItems", "minLength", "minProperties", "minimum", "multipleOf", "not", "nullable", "oneOf", "pattern", "patternProperties", "properties", "required", "title", "type", "uniqueItems", "x-kubernetes-embedded-resource", "x-kubernetes-int-or-string", "x-kubernetes-list-map-keys", "x-kubernetes-list-type", "x-kubernetes-map-type", "x-kubernetes-preserve-unknown-fields", "x-kubernetes-validations"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1JSONSchemaProps:
        """Create an instance of V1JSONSchemaProps from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in all_of (list)
        _items = []
        if self.all_of:
            for _item in self.all_of:
                if _item:
                    _items.append(_item.to_dict())
            _dict['allOf'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in any_of (list)
        _items = []
        if self.any_of:
            for _item in self.any_of:
                if _item:
                    _items.append(_item.to_dict())
            _dict['anyOf'] = _items
        # override the default output from pydantic by calling `to_dict()` of each value in definitions (dict)
        _field_dict = {}
        if self.definitions:
            for _key in self.definitions:
                if self.definitions[_key]:
                    _field_dict[_key] = self.definitions[_key].to_dict()
            _dict['definitions'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of external_docs
        if self.external_docs:
            _dict['externalDocs'] = self.external_docs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_not
        if self.var_not:
            _dict['not'] = self.var_not.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in one_of (list)
        _items = []
        if self.one_of:
            for _item in self.one_of:
                if _item:
                    _items.append(_item.to_dict())
            _dict['oneOf'] = _items
        # override the default output from pydantic by calling `to_dict()` of each value in pattern_properties (dict)
        _field_dict = {}
        if self.pattern_properties:
            for _key in self.pattern_properties:
                if self.pattern_properties[_key]:
                    _field_dict[_key] = self.pattern_properties[_key].to_dict()
            _dict['patternProperties'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in properties (dict)
        _field_dict = {}
        if self.properties:
            for _key in self.properties:
                if self.properties[_key]:
                    _field_dict[_key] = self.properties[_key].to_dict()
            _dict['properties'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each item in x_kubernetes_validations (list)
        _items = []
        if self.x_kubernetes_validations:
            for _item in self.x_kubernetes_validations:
                if _item:
                    _items.append(_item.to_dict())
            _dict['x-kubernetes-validations'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1JSONSchemaProps:
        """Create an instance of V1JSONSchemaProps from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1JSONSchemaProps.parse_obj(obj)

        _obj = V1JSONSchemaProps.parse_obj({
            "ref": obj.get("$ref"),
            "var_schema": obj.get("$schema"),
            "additional_items": obj.get("additionalItems"),
            "additional_properties": obj.get("additionalProperties"),
            "all_of": [V1JSONSchemaProps.from_dict(_item) for _item in obj.get("allOf")] if obj.get("allOf") is not None else None,
            "any_of": [V1JSONSchemaProps.from_dict(_item) for _item in obj.get("anyOf")] if obj.get("anyOf") is not None else None,
            "default": obj.get("default"),
            "definitions": dict(
                (_k, V1JSONSchemaProps.from_dict(_v))
                for _k, _v in obj.get("definitions").items()
            )
            if obj.get("definitions") is not None
            else None,
            "dependencies": obj.get("dependencies"),
            "description": obj.get("description"),
            "enum": obj.get("enum"),
            "example": obj.get("example"),
            "exclusive_maximum": obj.get("exclusiveMaximum"),
            "exclusive_minimum": obj.get("exclusiveMinimum"),
            "external_docs": V1ExternalDocumentation.from_dict(obj.get("externalDocs")) if obj.get("externalDocs") is not None else None,
            "format": obj.get("format"),
            "id": obj.get("id"),
            "items": obj.get("items"),
            "max_items": obj.get("maxItems"),
            "max_length": obj.get("maxLength"),
            "max_properties": obj.get("maxProperties"),
            "maximum": obj.get("maximum"),
            "min_items": obj.get("minItems"),
            "min_length": obj.get("minLength"),
            "min_properties": obj.get("minProperties"),
            "minimum": obj.get("minimum"),
            "multiple_of": obj.get("multipleOf"),
            "var_not": V1JSONSchemaProps.from_dict(obj.get("not")) if obj.get("not") is not None else None,
            "nullable": obj.get("nullable"),
            "one_of": [V1JSONSchemaProps.from_dict(_item) for _item in obj.get("oneOf")] if obj.get("oneOf") is not None else None,
            "pattern": obj.get("pattern"),
            "pattern_properties": dict(
                (_k, V1JSONSchemaProps.from_dict(_v))
                for _k, _v in obj.get("patternProperties").items()
            )
            if obj.get("patternProperties") is not None
            else None,
            "properties": dict(
                (_k, V1JSONSchemaProps.from_dict(_v))
                for _k, _v in obj.get("properties").items()
            )
            if obj.get("properties") is not None
            else None,
            "required": obj.get("required"),
            "title": obj.get("title"),
            "type": obj.get("type"),
            "unique_items": obj.get("uniqueItems"),
            "x_kubernetes_embedded_resource": obj.get("x-kubernetes-embedded-resource"),
            "x_kubernetes_int_or_string": obj.get("x-kubernetes-int-or-string"),
            "x_kubernetes_list_map_keys": obj.get("x-kubernetes-list-map-keys"),
            "x_kubernetes_list_type": obj.get("x-kubernetes-list-type"),
            "x_kubernetes_map_type": obj.get("x-kubernetes-map-type"),
            "x_kubernetes_preserve_unknown_fields": obj.get("x-kubernetes-preserve-unknown-fields"),
            "x_kubernetes_validations": [V1ValidationRule.from_dict(_item) for _item in obj.get("x-kubernetes-validations")] if obj.get("x-kubernetes-validations") is not None else None
        })
        return _obj

V1JSONSchemaProps.update_forward_refs()

