# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class V2CrossVersionObjectReference(BaseModel):
    """
    CrossVersionObjectReference contains enough information to let you identify the referred resource.  # noqa: E501
    """
    api_version: Optional[StrictStr] = Field(None, alias="apiVersion", description="apiVersion is the API version of the referent")
    kind: StrictStr = Field(..., description="kind is the kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds")
    name: StrictStr = Field(..., description="name is the name of the referent; More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names")
    __properties = ["apiVersion", "kind", "name"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V2CrossVersionObjectReference:
        """Create an instance of V2CrossVersionObjectReference from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V2CrossVersionObjectReference:
        """Create an instance of V2CrossVersionObjectReference from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V2CrossVersionObjectReference.parse_obj(obj)

        _obj = V2CrossVersionObjectReference.parse_obj({
            "api_version": obj.get("apiVersion"),
            "kind": obj.get("kind"),
            "name": obj.get("name")
        })
        return _obj


